aboutsummaryrefslogtreecommitdiffstats
path: root/apps/CA.pl
diff options
context:
space:
mode:
authorPaul C. Sutton <paul@openssl.org>1999-01-02 16:02:24 +0000
committerPaul C. Sutton <paul@openssl.org>1999-01-02 16:02:24 +0000
commitc142bdf7251470923ef5eecde97cd6c1be99bc16 (patch)
treefffc335dcd061efda142eff60ec6cda38683a153 /apps/CA.pl
parentc9f06e7f9f68c3652f0d396901e61bb947ed85f3 (diff)
downloadopenssl-c142bdf7251470923ef5eecde97cd6c1be99bc16.tar.gz
Update scripts to use "openssl" instead of "ssleay"
Diffstat (limited to 'apps/CA.pl')
-rwxr-xr-xapps/CA.pl10
1 files changed, 5 insertions, 5 deletions
diff --git a/apps/CA.pl b/apps/CA.pl
index 7f71f4a768..901f8c99fb 100755
--- a/apps/CA.pl
+++ b/apps/CA.pl
@@ -33,14 +33,14 @@
# Steve Henson
# shenson@bigfoot.com
# default ssleay.cnf file has setup as per the following
# demoCA ... where everything is stored
$DAYS="-days 365";
-$REQ="ssleay req $SSLEAY_CONFIG";
-$CA="ssleay ca $SSLEAY_CONFIG";
-$VERIFY="ssleay verify";
-$X509="ssleay x509";
+$REQ="openssl req $SSLEAY_CONFIG";
+$CA="openssl ca $SSLEAY_CONFIG";
+$VERIFY="openssl verify";
+$X509="openssl x509";
$CATOP="./demoCA";
$CAKEY="cakey.pem";
@@ -33,14 +33,14 @@
# Steve Henson
# shenson@bigfoot.com
-# default ssleay.cnf file has setup as per the following
+# default openssl.cnf file has setup as per the following
# demoCA ... where everything is stored
$DAYS="-days 365";